from .exceptions import APIError
from .api import make_request
import uuid

class MediaResource:
    def __init__(self, client):
        self.client = client
    
    def get_all(self,params=None):
        """Fetch all medias."""
        try:
            return make_request(
                method="GET", 
                endpoint="/on-demand", 
                headers=self.client.headers,
                params=params
            )
        except APIError as e:
            raise APIError(f"Failed to fetch medias: {str(e)}")

    def get_by_id(self, media_id):
        """Fetch media by its ID."""
        try:
            print(f"Received media_id: {media_id}")
            
            # Validate if media_id is a valid UUID
            try:
                uuid_obj = uuid.UUID(media_id)
            except ValueError:
                raise AssertionError(f"Invalid UUID: {media_id} is not a valid UUID.")

            response = make_request(
                method="GET", 
                endpoint=f"/on-demand/{media_id}", 
                headers=self.client.headers
            )
            
            return response
        
        # except AssertionError as assert_error:
        #     print(f"AssertionError: {assert_error}")
        #     raise assert_error
        
        except APIError as api_error:
            print(f"APIError: {api_error}")
            raise APIError(f"Failed to fetch media: {str(api_error)}")
        
        except Exception as e:
            print(f"Unexpected error: {e}")
            raise e

    def update(self, media_id, data):
        """Update media by its ID."""
        if not media_id:
            raise ValueError("Media ID must be provided.")
        
        try:
            return make_request(
                method="PATCH", 
                endpoint=f"/on-demand/{media_id}", 
                headers=self.client.headers,
                data=data
            )
        except APIError as e:
            raise APIError(f"Failed to update media: {str(e)}")

    def delete(self, media_id):
        """Delete media by its ID."""
        if not media_id:
            raise ValueError("Media ID must be provided.")
        
        try:
            return make_request(
                method="DELETE", 
                endpoint=f"/on-demand/{media_id}", 
                headers=self.client.headers
            )
        except APIError as e:
            raise APIError(f"Failed to delete media: {str(e)}")

    def create_pull_video(self, data):
        """Create an on-demand request by calling the /on-demand endpoint."""
        endpoint = "/on-demand"
        
        if "accessPolicy" not in data:
            data["accessPolicy"] = "public"
        
        try:
            response = make_request(
                method="POST", 
                endpoint=endpoint, 
                headers=self.client.headers, 
                data=data
            )
            return response
        except APIError as e:
            raise APIError(f"Failed to create on-demand request: {str(e)}")

    def get_presigned_url(self, data):
        """Create an on-demand presigned URL request by calling the /on-demand/uploads endpoint."""
        endpoint = "/on-demand/uploads"
        
        if "corsOrigin" not in data:
            data["corsOrigin"] = "*"
        
        try:
            response = make_request(
                method="POST", 
                endpoint=endpoint, 
                headers=self.client.headers, 
                data=data
            )
            return response
        except APIError as e:
            raise APIError(f"Failed to create presigned URL request: {str(e)}")

    def get_media_info(self, media_id):
        """Retrieve media input info by media ID."""
        if not media_id:
            raise ValueError("Media ID must be provided.")
        
        try:
            endpoint = f"/on-demand/{media_id}/input-info"
            
            return make_request(
                method="GET", 
                endpoint=endpoint, 
                headers=self.client.headers
            )
        except APIError as e:
            raise APIError(f"Failed to retrieve media input info: {str(e)}")
            
            